..
      Copyright 2014-2015 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=================================
Welcome to Kolla's documentation!
=================================

Kolla's mission is to provide production-ready containers and deployment tools
for operating OpenStack clouds.

This documentation is for the Kolla container images. The following subprojects
are available to help deploy Kolla:

* `kolla-ansible <https://docs.openstack.org/kolla-ansible/latest/>`_

Site Notes
==========

This documentation is continually updated and may not represent the state of
the project at any specific prior release. To access documentation for a
previous release of kolla, append the OpenStack release name to the URL. For
example, to access Kolla documentation for pike release:
https://docs.openstack.org/kolla/pike

Administrator Guide
===================

.. toctree::
   :maxdepth: 2

   admin/index

Contributor Guide
=================

.. toctree::
   :maxdepth: 2

   contributor/index
